# Toolchain builder for the Serene programming language
#
# Copyright (c) 2019-2023 Sameer Rahmani <lxsameer@gnu.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import shutil
from pathlib import Path

from conan import ConanFile
from conan.tools.files import get, copy
from conan.tools.cmake import CMakeToolchain

import os


class GCC(ConanFile):
    name = "gcc"
    version = "latest"
    settings = "os", "arch"
    tc_type = "cross"
    exports = ("*.cmake",)
    target = "x86_64-linux-musl"

    @property
    def toolchain_vars(self):
        return {
            "CMAKE_C_COMPILER": "x86_64-linux-musl-gcc",
            "CMAKE_CXX_COMPILER": "x86_64-linux-musl-g++",
            "CMAKE_AS_COMPILER": "x86_64-linux-musl-gcc",
            "CMAKE_FIND_ROOT_PATH_MODE_PROGRAM": "NEVER",
            "CMAKE_FIND_ROOT_PATH_MODE_LIBRARY": "ONLY",
            "CMAKE_FIND_ROOT_PATH_MODE_INCLUDE": "ONLY",
            "CMAKE_FIND_ROOT_PATH_MODE_PACKAGE": "ONLY",
        }

    def build(self):
        copy(self, "gcc-musl-toolchain.cmake", self.recipe_folder, self.package_folder)
        get(
            self,
            f"http://musl.cc/{self.target}-{self.tc_type}.tgz",
            destination=self.package_folder,
            filename=f"{self.target}-{self.tc_type}.tgz",
            keep_permissions=True,
            strip_root=True,
        )

    def package_info(self):
        bindir = Path(os.path.join(self.package_folder, "bin"))
        self.runenv_info.prepend_path(
            "PATH",
            str(bindir),
        )
        f = os.path.join(self.package_folder, "gcc-musl-toolchain.cmake")

        self.buildenv_info.append("sysroot", self.package_folder)
        self.conf_info.prepend("tools.cmake.cmaketoolchain:user_toolchain", f)

        self.conf_info.define("tools.build:sysroot", self.package_folder)
        self.buildenv_info.define_path("SYSROOT", self.package_folder)

        self.buildenv_info.define("CC", str(bindir / f"{self.target}-gcc"))
        self.buildenv_info.define("CXX", str(bindir / f"{self.target}-g++"))
        self.buildenv_info.define("AR", str(bindir / f"{self.target}-ar"))
        self.buildenv_info.define("NM", str(bindir / f"{self.target}-nm"))
        self.buildenv_info.define("RANLIB", str(bindir / f"{self.target}-ranlib"))
