# Toolchain builder for the Serene programming language
#
# Copyright (c) 2019-2023 Sameer Rahmani <lxsameer@gnu.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import os

from conan import ConanFile
from conan.tools.cmake import CMake, CMakeToolchain, CMakeDeps
from conan.tools.files import get

from conf.utils import with_static_flags, get_version, with_musl_toolchain


class Ninja(ConanFile):
    name = "ninja"
    settings = "os", "arch", "build_type"
    version = get_version("ninja")

    options = {
        "libc": ["glibc", "musl"],
    }
    default_options = {"libc": "glibc"}

    def requirements(self):
        self.tool_requires(f"cmake/{get_version('cmake')}@{self.user}/{self.channel}")

        # if self.options.libc == "musl":
        #     self.requires(
        #         f"stage2-sysroot/{get_version('llvm')}@{self.user}/{self.channel}"
        #     )

    def source(self):
        get(
            self,
            f"https://github.com/ninja-build/ninja/archive/v{self.version}.tar.gz",
        )

    def configure(self):
        self.settings.rm_safe("compiler.cppstd")

    def generate(self):
        tc = CMakeToolchain(self)
        if self.options.libc == "musl":
            with_musl_toolchain(self, tc)

        tc.generate()
        deps = CMakeDeps(self)
        deps.generate()

    def package_id(self):
        # No need to delete those settings here, they were already deleted
        pass

    def build(self):
        cmake = CMake(self)
        flags = with_static_flags()

        cmake.configure(
            flags,
            build_script_folder=f"ninja-{self.version}",
        )
        cmake.build()
        cmake.install()

    def package_info(self):
        self.buildenv_info.prepend_path(
            "PATH", os.path.join(self.package_folder, "bin")
        )
